# Common PHPStan configuration for WP Desk

This meta-package contains PHPStan configuration for WP Desk projects. This includes dependent extensions like `szepeviktor/phpstan-wordpress`, and additional, default configuration like inclusion of WooCommerce stubs.

## Installation

```sh
composer require wpdesk/phpstan-rules
```

## Usage

After installation, you can simply use PHPStan in your project without the need to further configuration. Nevertheless, as project grows, it's worth to add even [the basic one](https://phpstan.org/config-reference).

To run PHPStan, simply execute the following command (`<path>` is only required if not present in configuration file):

```sh
vendor/bin/phpstan analyse <path>
```

### Dependencies between plugins

Besides WordPress and WooCommerce, it may be sometimes necessary to analyse dependencies between plugins, e.g. when developing an extension to base plugin, PHPStan needs to be aware of the dependent plugin's codebase.

In such cases it is necessary to generate the stubs for the dependent plugin with the use of [stub generator library](https://github.com/php-stubs/generator). Try to install it as system-wide utility, rather than plugin's package.

```sh
composer global require php-stubs/generator
```

With the aid of this library, you will be able to provide read-only access to the dependent codebase for PHPStan purposes. Use `stub` extension to ignore this file by your editor analyzers.

```sh
generate-stubs --out=/path/to/.stubs/dependency.stub -- /path/to/dependency/src
```

Remember to regenerate the stubs, whenever there's an important change in upstream plugin.

Finally, include generated stubs in your PHPStan configuration.

```neon
parameters:
  scanFiles:
    - .stubs/dependency.stub
```
